@@ -3,7 +3,7 @@ use warnings;
 package WebService::KVV::Live::Stop;
 
 # ABSTRACT: Arrival times for Trams/Buses in the Karlsruhe metropolitan area
-our $VERSION = '0.001'; # VERSION
+our $VERSION = '0.002'; # VERSION
 
 use Carp;
 use utf8;
@@ -26,7 +26,7 @@ WebService::KVV::Live::Stop - Arrival times for Trams/Buses in the Karlsruhe met
     use WebService::KVV::Live::Stop;
 
     my $stop = WebService::KVV::Live::Stop->new("Siemensallee");
-    print "Arrival time: $_->{time} $_->{what}\n" for $stop->departures;
+    print "Arrival time: $_->{time} $_->{route} $_->{destination}\n" for $stop->departures;
 
 
 =head1 DESCRIPTION
